
/*****
      CC_Configuration.h -
      Header definitions for ZWave parameter configuration support.
      Only Version 1.

      c 2019-2020 Primordial Machine Vision Systems
*****/

#ifndef __CC_CONFIG_H
#define __CC_CONFIG_H

#include <ZW_classcmd.h>
#include <ZW_TransportEndpoint.h>


/**** Application Interface ****/

/* These are not implemented in the command class.  The application must
   do that. */

/* return the paramID or a default (1) if invalid, for the _REPORT
     paramID - parameter identifier
*/
extern uint8_t appConfigValidParam(uint8_t paramID);

/* return the value of the parameter - the size of the data may be smaller
   if paramID doesn't exist then return the value of parameter 1
     paramID - parameter identifier
*/
extern int32_t appConfigValue(uint8_t paramID);

/* return the size byte for _REPORT
     paramID - parameter identifier
*/
extern uint8_t appConfigLevel(uint8_t paramID);

/* change the value of the parameter, does nothing if parameter not supported
     paramID - parameter identifier
     val - new value
     dflt - if true, set value to application default
   returns true if parameter set (even if value doesn't change), 0 if can't
*/
extern bool appConfigSet(uint8_t paramID, int32_t val, uint8_t dflt);



/**** Command Class Interface ****/

/* command handler
     rxopt - receive packet options
     rxcmd - incoming command buffer
     rxlen - number of bytes in rxcmd
   returns RECEIVED_FRAME_STATUS_* flag
*/
extern received_frame_status_t
handleCCConfiguration(RECEIVE_OPTIONS_TYPE_EX *rxopt,
                      ZW_APPLICATION_TX_BUFFER *rxcmd, uint8_t rxlen);


#endif     /* __CC_CONFIG_H */
